@@ -8,6 +8,8 @@ from . import (
     rev6,
     rev7,
     rev8,
+    rev9,
+    rev10,
 )
 
 revisions = {
@@ -20,4 +22,6 @@ revisions = {
     6: rev6,
     7: rev7,
     8: rev8,
+    9: rev9,
+    10: rev10,
 }
